from setuptools import setup

setup(
    name = 'cedisa_report',
    version = '1.2.0',
    author = 'Gustavo Gomes Dias',
    author_email = 'gustavo.dias@cedisa.com.br',
    packages = ['cedisa_report']
)